@@ -1,4 +1,4 @@
-library("symbolicDA")
+require(symbolicDA)
 data("cars",package="symbolicDA")
 sdt<-cars
 clust<-SClust(sdt, cl=3, iter=50)
