@@ -1,4 +1,4 @@
 require(symbolicDA)
 data("cars",package="symbolicDA")
-dist<-dist.SDA(cars, type="U_3", gamma=0.3, power=2)
+dist<-dist_SDA(cars, type="U_3", gamma=0.3, power=2)
 print(dist)
